==> cscec5b-op-impl-3.0.0-20220921.085300-6-sources.jar: com/ejianc/business/op/controller/ConfigCheckerController.java <==
package com.ejianc.business.op.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.op.bean.ConfigCheckerEntity;
import com.ejianc.business.op.service.IConfigCheckerService;
import com.ejianc.business.op.vo.ConfigCheckerVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.io.Serializable;
import java.util.List;

/**
 * 核验人员实体
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("configChecker")
public class ConfigCheckerController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IConfigCheckerService configCheckerService;


    @RequestMapping(value = "/saveBatch", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> saveBatch(@RequestBody List<ConfigCheckerVO> checkerVOS) {
        configCheckerService.saveBatch(checkerVOS);
    	return CommonResponse.success("保存单据成功！");
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> deleteById(Long id) {
        configCheckerService.removeById(id, true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ConfigCheckerVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));

        IPage<ConfigCheckerEntity> page = configCheckerService.queryPage(param,false);
        IPage<ConfigCheckerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ConfigCheckerVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}

==> cscec5b-op-impl-3.0.0-20240124.105106-73-sources.jar: com/ejianc/business/op/controller/ConfigCheckerController.java <==
package com.ejianc.business.op.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.op.bean.ConfigCheckerEntity;
import com.ejianc.business.op.service.IConfigCheckerService;
import com.ejianc.business.op.vo.ConfigCheckerVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 核验人员实体
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("configChecker")
public class ConfigCheckerController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IConfigCheckerService configCheckerService;


    @RequestMapping(value = "/saveBatch", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> saveBatch(@RequestBody List<ConfigCheckerVO> checkerVOS) {
        configCheckerService.saveBatch(checkerVOS);
    	return CommonResponse.success("保存单据成功！");
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> deleteById(Long id) {
        configCheckerService.removeById(id, true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ConfigCheckerVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));

        IPage<ConfigCheckerEntity> page = configCheckerService.queryPage(param,false);
        IPage<ConfigCheckerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ConfigCheckerVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "/queryCheckerByProj", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> queryCheckerByProj(@RequestParam("projectId") Long projectId) {
        LambdaQueryWrapper<ConfigCheckerEntity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ConfigCheckerEntity::getProjectId, projectId);
        List<ConfigCheckerEntity> checkerEntities = configCheckerService.list(queryWrapper);
        String nameStr = null;
        if(CollectionUtils.isNotEmpty(checkerEntities)){
            List<String> nameList = checkerEntities.stream().map(ConfigCheckerEntity::getName).collect(Collectors.toList());
            nameStr = StringUtils.join(nameList, ",");
        }
        return CommonResponse.success("查询项目下核验人员成功",  nameStr);
    }

}
